# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: com/navercorp/scavenger/model/CommonPublicationData.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9com/navercorp/scavenger/model/CommonPublicationData.proto\"\xe3\x01\n\x15\x43ommonPublicationData\x12\x0f\n\x07\x61pi_key\x18\x01 \x01(\t\x12\x10\n\x08\x61pp_name\x18\x02 \x01(\t\x12\x13\n\x0b\x61pp_version\x18\x03 \x01(\t\x12\x1d\n\x15\x63ode_base_fingerprint\x18\x04 \x01(\t\x12\x13\n\x0b\x65nvironment\x18\x05 \x01(\t\x12\x10\n\x08hostname\x18\x06 \x01(\t\x12\x1d\n\x15jvm_started_at_millis\x18\x07 \x01(\x03\x12\x10\n\x08jvm_uuid\x18\x08 \x01(\t\x12\x1b\n\x13published_at_millis\x18\t \x01(\x03\x42!\n\x1d\x63om.navercorp.scavenger.modelP\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.navercorp.scavenger.model.CommonPublicationData_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035com.navercorp.scavenger.modelP\001'
  _COMMONPUBLICATIONDATA._serialized_start=62
  _COMMONPUBLICATIONDATA._serialized_end=289
# @@protoc_insertion_point(module_scope)
