# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: com/navercorp/scavenger/model/InvocationDataPublication.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from scavenger.model import CommonPublicationData_pb2 as com_dot_navercorp_dot_scavenger_dot_model_dot_CommonPublicationData__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=com/navercorp/scavenger/model/InvocationDataPublication.proto\x1a\x39\x63om/navercorp/scavenger/model/CommonPublicationData.proto\"\xda\x01\n\x19InvocationDataPublication\x12+\n\x0b\x63ommon_data\x18\x01 \x01(\x0b\x32\x16.CommonPublicationData\x12=\n\x05\x65ntry\x18\x02 \x03(\x0b\x32..InvocationDataPublication.InvocationDataEntry\x12,\n$recording_interval_started_at_millis\x18\x03 \x01(\x03\x1a#\n\x13InvocationDataEntry\x12\x0c\n\x04hash\x18\x01 \x01(\tB!\n\x1d\x63om.navercorp.scavenger.modelP\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.navercorp.scavenger.model.InvocationDataPublication_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035com.navercorp.scavenger.modelP\001'
  _INVOCATIONDATAPUBLICATION._serialized_start=125
  _INVOCATIONDATAPUBLICATION._serialized_end=343
  _INVOCATIONDATAPUBLICATION_INVOCATIONDATAENTRY._serialized_start=308
  _INVOCATIONDATAPUBLICATION_INVOCATIONDATAENTRY._serialized_end=343
# @@protoc_insertion_point(module_scope)
