# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: com/navercorp/scavenger/model/GetConfig.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-com/navercorp/scavenger/model/GetConfig.proto\"5\n\x10GetConfigRequest\x12\x0f\n\x07\x61pi_key\x18\x01 \x01(\t\x12\x10\n\x08jvm_uuid\x18\x02 \x01(\t\"\xbb\x02\n\x11GetConfigResponse\x12$\n\x1c\x63onfig_poll_interval_seconds\x18\x01 \x01(\x05\x12*\n\"config_poll_retry_interval_seconds\x18\x02 \x01(\x05\x12\x32\n*code_base_publisher_check_interval_seconds\x18\x03 \x01(\x05\x12\x32\n*code_base_publisher_retry_interval_seconds\x18\x04 \x01(\x05\x12\x32\n*invocation_data_publisher_interval_seconds\x18\x05 \x01(\x05\x12\x38\n0invocation_data_publisher_retry_interval_seconds\x18\x06 \x01(\x05\x42!\n\x1d\x63om.navercorp.scavenger.modelP\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.navercorp.scavenger.model.GetConfig_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035com.navercorp.scavenger.modelP\001'
  _GETCONFIGREQUEST._serialized_start=49
  _GETCONFIGREQUEST._serialized_end=102
  _GETCONFIGRESPONSE._serialized_start=105
  _GETCONFIGRESPONSE._serialized_end=420
# @@protoc_insertion_point(module_scope)
