# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: com/navercorp/scavenger/model/GrpcAgentService.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from scavenger.model import GetConfig_pb2 as com_dot_navercorp_dot_scavenger_dot_model_dot_GetConfig__pb2
from scavenger.model import CodeBasePublication_pb2 as com_dot_navercorp_dot_scavenger_dot_model_dot_CodeBasePublication__pb2
from scavenger.model import InvocationDataPublication_pb2 as com_dot_navercorp_dot_scavenger_dot_model_dot_InvocationDataPublication__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4com/navercorp/scavenger/model/GrpcAgentService.proto\x1a-com/navercorp/scavenger/model/GetConfig.proto\x1a\x37\x63om/navercorp/scavenger/model/CodeBasePublication.proto\x1a=com/navercorp/scavenger/model/InvocationDataPublication.proto\"%\n\x13PublicationResponse\x12\x0e\n\x06status\x18\x01 \x01(\t2\xe7\x01\n\x10GrpcAgentService\x12\x35\n\nPollConfig\x12\x11.GetConfigRequest\x1a\x12.GetConfigResponse\"\x00\x12G\n\x17SendCodeBasePublication\x12\x14.CodeBasePublication\x1a\x14.PublicationResponse\"\x00\x12S\n\x1dSendInvocationDataPublication\x12\x1a.InvocationDataPublication\x1a\x14.PublicationResponse\"\x00\x42!\n\x1d\x63om.navercorp.scavenger.modelP\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.navercorp.scavenger.model.GrpcAgentService_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035com.navercorp.scavenger.modelP\001'
  _PUBLICATIONRESPONSE._serialized_start=223
  _PUBLICATIONRESPONSE._serialized_end=260
  _GRPCAGENTSERVICE._serialized_start=263
  _GRPCAGENTSERVICE._serialized_end=494
# @@protoc_insertion_point(module_scope)
